@@ -17,8 +17,8 @@ def main() -> None:
 
 """
 <output>
-interface_unknown.py:7: error: Cannot find implementation or library stub for module named 'unknown'
-interface_unknown.py:7: note: See https://mypy.readthedocs.io/en/latest/running_mypy.html#missing-imports
-interface_unknown.py:15: note: Revealed type is 'Any'
+interface_unknown.py:7: error: Cannot find implementation or library stub for module named "unknown"
+interface_unknown.py:7: note: See https://mypy.readthedocs.io/en/stable/running_mypy.html#missing-imports
+interface_unknown.py:15: note: Revealed type is "Any"
 </output>
 """
